import { decodeKeyVault, deriveKeyVault, encodeKeyVault, type KeyVault } from "./crypto";

export function loggedIn() {
    if (typeof window !== 'object') return false;
    const vault = localStorage['_vault'] ?? sessionStorage['_vault'];
    return !!vault;
}

export async function login(passkey: string, persistent: boolean = false): Promise<KeyVault> {
    const storage = persistent ? localStorage : sessionStorage;

    const keyVault = await deriveKeyVault(passkey);
    storage['_vault'] = encodeKeyVault(keyVault);
    return keyVault;
}

export function getKeyVault(): KeyVault | null {
    try {
        const vault = localStorage['_vault'] ?? sessionStorage['_vault'];
        return decodeKeyVault(vault);
    } catch (e) {
        console.log(e);
        return null;
    }
}

export function logout() {
    delete localStorage['_vault'];
    delete sessionStorage['_vault'];
}

